@@ -1,4 +1,12 @@
-"""This module will expand later."""
+"""This module includes all relevant classes and functions so that
+friendly-traceback can give help with warnings.
+
+It contains one function (``enable_warnings``) which is part of the API,
+and one (``get_warning_parser``) which is the only other function in this module
+which is intended to be part of the public API. However, while the latter
+can be imported using ``from friendly_traceback import enable_warnings``,
+``get_warning_parser`` needs to be imported from this module.
+"""
 import inspect
 import sys
 import warnings
@@ -24,6 +32,21 @@ if "pytest" in sys.modules:
     _run_with_pytest = True
 
 
+def enable_warnings():
+    """Used to enable all warnings, with 'always' being used as the
+    parameter for warnings.simplefilter.
+
+    While friendly_traceback, used by many third-party packages, does not
+    automatically handle warnings by default, friendly, which is meant to
+    be used by end-users instead of other packages/libraries, does call
+    enable_warnings by default.
+    """
+    # Note: enable_warnings is imported by friendly_traceback.__init__
+    # so that it is part of the public API.
+    warnings.simplefilter("always")
+    warnings.showwarning = show_warning
+
+
 class MyFormatter(Formatter):
     def format_frame(self, frame):
         yield from super().format_frame(frame)
@@ -42,21 +65,21 @@ class WarningInfo:
         self.lines = lines
         self.frame = frame
         self.info = {}
-        self.info["warning message"] = f"{warning_type.__name__}: {self.message}\n"
-        self.info["message"] = self.info["warning message"]
+        self.info["warning_message"] = f"{warning_type.__name__}: {self.message}\n"
+        self.info["message"] = self.info["warning_message"]
 
         if frame is not None:
             source = self.format_source()
-            self.info["warning source"] = source
+            self.info["warning_source"] = source
             self.problem_statement = executing.Source.executing(frame).text()
-            var_info = get_var_info(self.problem_line, frame)
-            self.info["warning variables"] = var_info["var_info"]
-            if "additional variable warning" in var_info:
-                self.info["additional variable warning"] = var_info[
-                    "additional variable warning"
+            var_info = get_var_info(self.problem_statement, frame)
+            self.info["warning_variables"] = var_info["var_info"]
+            if "additional_variable_warning" in var_info:
+                self.info["additional_variable_warning"] = var_info[
+                    "additional_variable_warning"
                 ]
         else:
-            self.info["warning source"] = self.get_source_frame_missing()
+            self.info["warning_source"] = self.get_source_frame_missing()
         self.recompile_info()
 
     def recompile_info(self):
@@ -71,7 +94,7 @@ class WarningInfo:
             location = _(
                 "Warning issued on line `{line}` of file '{filename}'."
             ).format(filename=short_filename, line=self.lineno)
-        self.info["warning location header"] = location + "\n"
+        self.info["warning_location_header"] = location + "\n"
 
         self.info.update(**get_warning_cause(self.warning_type, self.message, self))
 
@@ -111,7 +134,10 @@ class WarningInfo:
                 self.lines if self.lines is not None else []
             )
             if not self.problem_statement:  # should not happen
-                formatted_source = _("<'source unavailable'>")
+                formatted_source = _(
+                    "The source is unavailable.\n"
+                    "If you used `exec`, consider using `friendly_exec` instead."
+                )
             else:  # assume single line
                 formatted_source = f"    -->{self.lineno}| " + self.problem_statement
             return formatted_source
@@ -147,6 +173,15 @@ def show_warning(
 ):
     if filename == "<>":  # internal to IPython
         return
+    if (  # friendly_idle causes these two warnings.
+        warning_type == ImportWarning
+        and str(warning_instance)
+        in [
+            "PatchingFinder.find_spec() not found; falling back to find_module()",
+            "PatchingLoader.exec_module() not found; falling back to load_module()",
+        ]
+    ):
+        return
     if saw_warning_before(
         warning_type.__name__, str(warning_instance), filename, lineno
     ):
@@ -155,18 +190,21 @@ def show_warning(
         # is repeated
         return
 
-    for outer_frame in inspect.getouterframes(inspect.currentframe()):
-        if outer_frame.filename == filename and outer_frame.lineno == lineno:
-            warning_data = WarningInfo(
-                warning_instance,
-                warning_type,
-                filename,
-                lineno,
-                frame=outer_frame.frame,
-                lines=outer_frame.code_context,
-            )
-            break
-    else:
+    try:
+        for outer_frame in inspect.getouterframes(inspect.currentframe()):
+            if outer_frame.filename == filename and outer_frame.lineno == lineno:
+                warning_data = WarningInfo(
+                    warning_instance,
+                    warning_type,
+                    filename,
+                    lineno,
+                    frame=outer_frame.frame,
+                    lines=outer_frame.code_context,
+                )
+                break
+        else:
+            warning_data = WarningInfo(warning_instance, warning_type, filename, lineno)
+    except Exception:
         warning_data = WarningInfo(warning_instance, warning_type, filename, lineno)
 
     message = str(warning_instance)
@@ -179,11 +217,6 @@ def show_warning(
     session.write_err(f"`{warning_type.__name__}`: {message}\n")
 
 
-def enable_warnings():
-    warnings.simplefilter("always")
-    warnings.showwarning = show_warning
-
-
 INCLUDED_PARSERS = {
     SyntaxWarning: "syntax_warning",
 }
@@ -209,7 +242,7 @@ class WarningDataParser:
     def add(self, func: Parser) -> None:
         """This method is meant to be used by projects that extend
         friendly-traceback. It is used as a decorator to add a message parser
-        to a list that is automatically updated.
+        to a list that is automatically updated::
 
             @instance.add
             def some_warning_parsers(message, traceback_data):
@@ -220,6 +253,24 @@ class WarningDataParser:
 
 
 def get_warning_parser(warning_type: Type[_E]) -> WarningDataParser:
+    """Gets a 'parser' to find the cause for a given warning.
+
+    Args:
+
+        warning_type: a warning class.
+
+    Usage::
+
+        parser = get_warning_parser(SomeSpecificWarning)
+
+        @parser.add
+        def some_meaningful_name(warning_message: str,
+                                 warning_data: WarningDataParser) -> dict:
+            if not handled_by_this_function(warning_message):
+                return {}  # let other parsers deal with it
+
+            ...
+    """
     if warning_type not in WARNING_DATA_PARSERS:
         WARNING_DATA_PARSERS[warning_type] = WarningDataParser()
         if warning_type in INCLUDED_PARSERS:
