@@ -3,7 +3,7 @@ ft_console.py
 ==========
 
 Adaptation of Python's console found in code.py so that it can be
-used to show some "friendly" tracebacks.
+used to show some friendly tracebacks.
 """
 import codeop  # need to import to exclude from tracebacks
 import os
@@ -26,7 +26,11 @@ from .typing_info import Formatter, InclusionChoice
 def type_friendly() -> str:
     # Explicit type as mypy cannot infer correctly the return type on its own here
     _: Callable[[str], str] = current_lang.translate
-    return _("Type 'Friendly' for help on special functions/methods.")
+    if sys.platform == "win32":
+        exit_ = _("Use exit() or Ctrl-Z plus Return to exit.") + "\n"
+    else:
+        exit_ = _("Use exit() or Ctrl-D to exit.") + "\n"
+    return exit_ + _("Type 'Friendly' for help on special functions/methods.")
 
 
 BANNER = "\nFriendly-traceback version {}. [Python version: {}]\n".format(
@@ -51,6 +55,11 @@ def rich_displayhook(value: Any) -> None:
     _old_displayhook(value)
 
 
+def toggle_prompt() -> None:
+    """Toggles the style of prompt to use in the console."""
+    session.ipython_prompt = not session.ipython_prompt
+
+
 class FriendlyTracebackConsole(InteractiveConsole):
     def __init__(
         self,
@@ -100,8 +109,8 @@ class FriendlyTracebackConsole(InteractiveConsole):
         with in some way (this is the same as runsource()).
         """
         # mypy cannot get the type information from InteractiveConsole in stdlib
-        self.buffer.append(line)  # type: ignore
-        source = "\n".join(self.buffer)  # type: ignore
+        self.buffer.append(line)
+        source = "\n".join(self.buffer)
 
         # Each valid code sample is saved with its own fake filename.
         # They are numbered consecutively to help understand
@@ -149,7 +158,7 @@ class FriendlyTracebackConsole(InteractiveConsole):
         line.
         """
         try:
-            code = self.compile(source, filename, symbol)  # type: ignore
+            code = self.compile(source, filename, symbol)
         except (OverflowError, SyntaxError, ValueError):
             # Case 1
             if session.installed:
@@ -235,6 +244,8 @@ def start_console(
     if local_vars is not None:
         # Make sure we don't overwrite with our own functions
         helpers.update(local_vars)
+    helpers["friendly_exec"] = friendly_traceback.friendly_exec
+    helpers["toggle_prompt"] = toggle_prompt
 
     console = FriendlyTracebackConsole(
         local_vars=helpers,
